@@ -2,7 +2,7 @@ REFUND_PATH = "/QosicBridge/user/refund"
 # MTN
 MTN_PAYMENT_PATH = "/QosicBridge/user/requestpayment"
 MTN_PAYMENT_STATUS_PATH = "/QosicBridge/user/gettransactionstatus"
-MTN_PREFIXES = ["97", "96", "66", "67", "61", "62", "69", "91", "90", "51"]
+MTN_PREFIXES = ["51", "52", "53", "61", "62", "66", "67", "69", "90", "91", "96", "97"]
 # MOOV
 MOOV_PAYMENT_PATH = "/QosicBridge/user/requestpaymentmv"
-MOOV_PREFIXES = ["68", "98", "99", "95", "94", "60", "64", "63", "65"]
+MOOV_PREFIXES = ["55", "60", "63", "64", "65", "68", "94", "95", "98", "99"]
